// Importing necessary functions from d3 library
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  format,
  line,
  area,
  curveBasis
} from 'd3';

// Renedering the SVG element from the HTML file
const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

// Defining a function to format the tick values on the X axis
const xAxisTickFormat = number =>
    format('.3s')(number)

const render = data => {
  
  // Defining the function to extract the X value from the data
  const xValue = d => d.Year;
  const xAxisLabel = 'Year';
  
  // Defining the function to extract the Y value from the data
  const yValue = d => d.Selling_Price;
  const circleRadius = 3;
  const yAxisLabel = 'Selling_Price';
  
  // Defining the margins for the chart
  const margin = { top: 10, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;  

  
  // Creating a scale for the X axis
  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

   // Creating a scale for the Y axis
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
   
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
 
  // Creating the X axis and styling it
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  
  // Creating the Y axis and styling it
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(11)
    .tickFormat(xAxisTickFormat);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  // Adding the label for the Y axis
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 3)
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  // Adding the label for the X axis
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 3)
      .text(xAxisLabel);
 
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)))
  	.curve(curveBasis);
 
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class', 'line-chart')
  	.attr('d', lineGenerator(data));
  
  g.append('path')
  	.attr('class', 'area-chart')
  	.attr('d', areaGenerator(data));
  
 
};

// CSV URL function
csv('https://gist.githubusercontent.com/Shivamaninaidu/8437ec09c24fa084630088b547570f7b/raw/95c633420631a445118f0ab105909068aafda3c7/fortuner.csv')
  .then(data => {
    data.forEach(d => {
      d.Selling_Price= +d.Selling_Price;

     d.Year = +d.Year;
    });
    render(data);
  	console.log(data);
  });